@@ -1,47 +1,60 @@
 import importlib.util
 
-if importlib.util.find_spec("aind_watchdog_service") is None:
+if importlib.util.find_spec("aind_data_transfer_service") is None:
     raise ImportError(
-        "The 'aind_watchdog_service' package is required to use this module. \
+        "The 'aind_data_transfer_service' package is required to use this module. \
             Install the optional dependencies defined in `project.toml' \
                 by running `pip install .[aind-services]`"
     )
 
 import datetime
+import importlib.metadata
 import json
 import logging
 import os
 import subprocess
 from os import PathLike
-from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, ClassVar, Dict, List, Optional, Union
+from pathlib import Path, PurePosixPath
+from typing import TYPE_CHECKING, Any, Callable, ClassVar, Dict, Generic, List, Optional, TypeVar, Union
 
-import aind_watchdog_service.models
+import aind_data_transfer_service.models.core
 import pydantic
 import requests
+import semver
 import yaml
 from aind_data_schema.core.metadata import CORE_FILES
-from aind_data_schema.core.session import Session as AdsSession
-from aind_watchdog_service.models.manifest_config import BucketType, ManifestConfig, ModalityConfigs, Platform
-from aind_watchdog_service.models.watch_config import WatchConfig
-from pydantic import BaseModel
+from pydantic import BaseModel, SerializeAsAny, TypeAdapter
 from requests.exceptions import HTTPError
+from typing_extensions import deprecated
 
 from .. import ui
-from ..data_mapper.aind_data_schema import AindDataSchemaSessionDataMapper
-from ..launcher._callable_manager import _Promise
+from ..launcher._callable_manager import Promise
 from ..services import ServiceSettings
+from ._aind_watchdog_models import (
+    DEFAULT_TRANSFER_ENDPOINT,
+    BucketType,
+    ManifestConfig,
+    Platform,
+    WatchConfig,
+)
 from ._base import DataTransfer
 
 if TYPE_CHECKING:
+    from ..data_mapper.aind_data_schema import AindDataSchemaSessionDataMapper, Session
     from ..launcher import Launcher
 else:
     Launcher = Any
+    Session = Any
+    AindDataSchemaSessionDataMapper = Any
 
 logger = logging.getLogger(__name__)
 
+TransferServiceTask = Dict[
+    str, Union[aind_data_transfer_service.models.core.Task, Dict[str, aind_data_transfer_service.models.core.Task]]
+]
+TSessionMapper = TypeVar("TSessionMapper", bound=AindDataSchemaSessionDataMapper)
 
-_JobConfigs = Union[ModalityConfigs, Callable[["WatchdogDataTransferService"], Union[ModalityConfigs]]]
+_AIND_DATA_SCHEMA_PKG_VERSION = semver.Version.parse(importlib.metadata.version("aind_data_schema"))
 
 
 class WatchdogSettings(ServiceSettings):
@@ -49,7 +62,7 @@ class WatchdogSettings(ServiceSettings):
     Settings for the WatchdogDataTransferService.
 
     Attributes:
-        destination (PathLike): The destination path for the data transfer.
+        destination (Path): The destination path for the data transfer.
         schedule_time (Optional[datetime.time]): The time to schedule the data transfer.
         project_name (str): The name of the project.
         platform (Platform): The platform of the project.
@@ -61,27 +74,29 @@ class WatchdogSettings(ServiceSettings):
         transfer_endpoint (str): The endpoint for the data transfer service.
         delete_modalities_source_after_success (bool): Whether to delete the source data after a successful transfer.
         extra_identifying_info (Optional[dict]): Extra identifying information for the data transfer.
-        upload_job_configs (Optional[Any]): Upload job configurations.
+        upload_tasks (Optional[Any]): Upload job configurations. Use the placeholder "{{ destination }}" to later reference the destination path.
+        job_config (str): Job configuration name.
     """
 
     __yml_section__: ClassVar[Optional[str]] = "watchdog"
 
-    destination: PathLike
+    destination: Path
     schedule_time: Optional[datetime.time] = datetime.time(hour=20)
     project_name: str
     platform: Platform = "behavior"
     capsule_id: Optional[str] = None
     script: Optional[Dict[str, List[str]]] = None
-    s3_bucket: BucketType = BucketType.PRIVATE
+    s3_bucket: BucketType = "private"
     mount: Optional[str] = None
     force_cloud_sync: bool = True
-    transfer_endpoint: str = "http://aind-data-transfer-service/api/v1/submit_jobs"
+    transfer_endpoint: str = DEFAULT_TRANSFER_ENDPOINT
     delete_modalities_source_after_success: bool = False
     extra_identifying_info: Optional[dict] = None
-    upload_job_configs: Optional[Any] = None
+    upload_tasks: Optional[SerializeAsAny[TransferServiceTask]] = None
+    job_type: str = "default"
 
 
-class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
+class WatchdogDataTransferService(DataTransfer[WatchdogSettings], Generic[TSessionMapper]):
     """
     A data transfer service that uses the aind-watchdog-service to monitor and transfer
     data based on manifest configurations.
@@ -93,7 +108,7 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
     Attributes:
         _source (PathLike): Source directory to monitor
         _settings (WatchdogSettings): Service settings containing destination and configuration
-        _aind_session_data_mapper (Optional[AindDataSchemaSessionDataMapper]): Mapper for session data
+        _aind_session_data_mapper (Optional[_TSessionMapper]): Mapper for session data
         _ui_helper (ui.UiHelper): UI helper for user prompts
         Various configuration attributes accessible via settings
 
@@ -136,6 +151,9 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         validate: bool = True,
         session_name: Optional[str] = None,
         ui_helper: Optional[ui.UiHelper] = None,
+        email_from_experimenter_builder: Optional[
+            Callable[[str], str]
+        ] = lambda user_name: f"{user_name}@alleninstitute.org",
     ) -> None:
         """
         Initializes the WatchdogDataTransferService.
@@ -178,8 +196,7 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         self._settings = settings
         self._source = source
 
-        self._aind_session_data_mapper: Optional[AindDataSchemaSessionDataMapper] = None
-        self._upload_job_configs: List[_JobConfigs] = []
+        self._aind_session_data_mapper: Optional[TSessionMapper] = None
 
         _default_exe = os.environ.get("WATCHDOG_EXE", None)
         _default_config = os.environ.get("WATCHDOG_CONFIG", None)
@@ -194,11 +211,18 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         self._manifest_config: Optional[ManifestConfig] = None
 
         self._validate_project_name = validate
+
+        if validate:
+            self.validate()
+
+        self._watch_config = WatchConfig.model_validate(self._read_yaml(self.config_path))
+
         self._ui_helper = ui_helper or ui.DefaultUIHelper()
         self._session_name = session_name
+        self._email_from_experimenter_builder = email_from_experimenter_builder
 
     @property
-    def aind_session_data_mapper(self) -> AindDataSchemaSessionDataMapper:
+    def aind_session_data_mapper(self) -> TSessionMapper:
         """
         Gets the aind-data-schema session data mapper.
 
@@ -212,7 +236,7 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             raise ValueError("Data mapper is not set.")
         return self._aind_session_data_mapper
 
-    def with_aind_session_data_mapper(self, value: AindDataSchemaSessionDataMapper) -> "WatchdogDataTransferService":
+    def with_aind_session_data_mapper(self, value: TSessionMapper) -> "WatchdogDataTransferService[TSessionMapper]":
         """
         Sets the aind-data-schema session data mapper.
 
@@ -252,10 +276,19 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             if not self.aind_session_data_mapper.is_mapped():
                 raise ValueError("Data mapper has not been mapped yet.")
 
-            self._manifest_config = self.create_manifest_config_from_ads_session(
-                ads_session=self.aind_session_data_mapper.mapped,
-                session_name=self._session_name,
-            )
+            if _AIND_DATA_SCHEMA_PKG_VERSION.major < 2:
+                logger.warning(
+                    "Using deprecated AIND data schema version %s. Consider upgrading.", _AIND_DATA_SCHEMA_PKG_VERSION
+                )
+                self._manifest_config = self._create_manifest_config_from_ads_session(
+                    ads_session=self.aind_session_data_mapper.mapped,
+                    session_name=self._session_name,
+                )
+            else:
+                self._manifest_config = self._create_manifest_config_from_ads_acquisition(
+                    ads_session=self.aind_session_data_mapper.mapped,
+                    session_name=self._session_name,
+                )
 
             if self._watch_config is None:
                 raise ValueError("Watchdog config is not set.")
@@ -270,16 +303,13 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             logger.error("Failed to create watchdog manifest config. %s", e)
             raise e
 
-    def validate(self, create_config: bool = True) -> bool:
+    def validate(self) -> bool:
         """
         Validates the Watchdog service and its configuration.
 
         Checks for required executables, configuration files, service status,
         and project name validity.
 
-        Args:
-            create_config: Whether to create a default configuration if missing
-
         Returns:
             True if the service is valid, False otherwise
 
@@ -291,15 +321,7 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         if not self.executable_path.exists():
             raise FileNotFoundError(f"Executable not found at {self.executable_path}")
         if not self.config_path.exists():
-            if not create_config:
-                raise FileNotFoundError(f"Config file not found at {self.config_path}")
-            else:
-                self._watch_config = self.create_watch_config(
-                    self.config_path.parent / "Manifests", self.config_path.parent / "Completed"
-                )
-                self._write_yaml(self._watch_config, self.config_path)
-        else:
-            self._watch_config = WatchConfig.model_validate(self._read_yaml(self.config_path))
+            raise FileNotFoundError(f"Config file not found at {self.config_path}")
 
         if not self.is_running():
             logger.warning(
@@ -309,62 +331,19 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             )
             return False
 
-        try:
-            _valid_proj = self.is_valid_project_name()
-            if not _valid_proj:
-                logger.warning("Watchdog project name is not valid.")
-        except HTTPError as e:
-            logger.error("Failed to fetch project names from endpoint. %s", e)
-            raise e
-        return _valid_proj
+        if self.settings.project_name is None:
+            logger.warning("Watchdog project name is not set. Skipping validation.")
+        else:
+            try:
+                _valid_proj = self.is_valid_project_name()
+                if not _valid_proj:
+                    logger.warning("Watchdog project name is not valid.")
+            except HTTPError as e:
+                logger.error("Failed to fetch project names from endpoint. %s", e)
+                raise e
+            return _valid_proj
 
-    @staticmethod
-    def create_watch_config(
-        watched_directory: os.PathLike,
-        manifest_complete_directory: os.PathLike,
-        create_dir: bool = True,
-    ) -> WatchConfig:
-        """
-        Creates a WatchConfig object for the Watchdog service.
-
-        Configures the directories and settings needed for the watchdog service
-        to monitor and process data transfer manifests.
-
-        Args:
-            watched_directory: Directory to monitor for changes
-            manifest_complete_directory: Directory for completed manifests
-            create_dir: Whether to create the directories if they don't exist
-
-        Returns:
-            A WatchConfig object
-
-        Example:
-            ```python
-            # Create basic watch configuration:
-            config = WatchdogDataTransferService.create_watch_config(
-                watched_directory="C:/watchdog/manifests",
-                manifest_complete_directory="C:/watchdog/completed"
-            )
-
-            # Create configuration with webhook:
-            config = WatchdogDataTransferService.create_watch_config(
-                watched_directory="C:/watchdog/manifests",
-                manifest_complete_directory="C:/watchdog/completed",
-                webhook_url="https://my-webhook.com/notify",
-                create_dir=True
-            )
-            ```
-        """
-        if create_dir:
-            if not Path(watched_directory).exists():
-                Path(watched_directory).mkdir(parents=True, exist_ok=True)
-            if not Path(manifest_complete_directory).exists():
-                Path(manifest_complete_directory).mkdir(parents=True, exist_ok=True)
-
-        return WatchConfig(
-            flag_dir=str(watched_directory),
-            manifest_complete=str(manifest_complete_directory),
-        )
+        return True
 
     def is_valid_project_name(self) -> bool:
         """
@@ -379,9 +358,101 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         project_names = self._get_project_names()
         return self._settings.project_name in project_names
 
-    def create_manifest_config_from_ads_session(
+    def _create_manifest_config_from_ads_acquisition(
         self,
-        ads_session: AdsSession,
+        ads_session: Session,
+        ads_schemas: Optional[List[os.PathLike]] = None,
+        session_name: Optional[str] = None,
+    ) -> ManifestConfig:
+        """
+        Creates a ManifestConfig object from an aind-data-schema acquisition.
+        This method should replace _create_manifest_config_from_ads_session for >2.0
+        aind-data-schema versions.
+
+        Converts acquisition metadata into a manifest configuration that can be
+        used by the watchdog service for data transfer operations.
+
+        Args:
+            ads_session: The aind-data-schema acquisition data
+            ads_schemas: Optional list of schema files
+            session_name: Name of the session
+
+        Returns:
+            A ManifestConfig object
+
+        Raises:
+            ValueError: If the project name is invalid
+
+        Example:
+            ```python
+            # Create manifest from acquisition data:
+            acquisition = Acquisition(...)
+            manifest = service.create_manifest_config_from_ads_acquisition(
+                ads_session=acquisition,
+            )
+
+            # Create with custom schemas:
+            schemas = ["C:/data/rig.json", "C:/data/processing.json"]
+            manifest = service.create_manifest_config_from_ads_acquisition(
+                ads_session=acquisition,
+                ads_schemas=schemas,
+            )
+            ```
+        """
+        processor_full_name = ",".join(ads_session.experimenters) or os.environ.get("USERNAME", "unknown")
+
+        if (len(ads_session.experimenters) > 0) and self._email_from_experimenter_builder is not None:
+            user_email = self._email_from_experimenter_builder(ads_session.experimenters[0])
+        else:
+            user_email = None
+
+        destination = Path(self._settings.destination).resolve()
+        source = Path(self._source).resolve()
+
+        if self._validate_project_name:
+            project_names = self._get_project_names()
+            if self._settings.project_name not in project_names:
+                raise ValueError(f"Project name {self._settings.project_name} not found in {project_names}")
+
+        ads_schemas = self._find_ads_schemas(source) if ads_schemas is None else ads_schemas
+
+        _manifest_config = ManifestConfig(
+            name=session_name,
+            modalities={
+                str(modality.abbreviation): [Path(path.resolve()) for path in [source / str(modality.abbreviation)]]
+                for modality in ads_session.data_streams[0].modalities
+            },
+            subject_id=int(ads_session.subject_id),
+            acquisition_datetime=ads_session.acquisition_start_time,
+            schemas=[Path(value) for value in ads_schemas],
+            destination=Path(destination),
+            mount=self._settings.mount,
+            processor_full_name=processor_full_name,
+            project_name=self._settings.project_name,
+            schedule_time=self._settings.schedule_time,
+            platform=self._settings.platform,
+            capsule_id=self._settings.capsule_id,
+            s3_bucket=self._settings.s3_bucket,
+            script=self._settings.script if self._settings.script else {},
+            force_cloud_sync=self._settings.force_cloud_sync,
+            transfer_endpoint=self._settings.transfer_endpoint,
+            delete_modalities_source_after_success=self._settings.delete_modalities_source_after_success,
+            extra_identifying_info=self._settings.extra_identifying_info,
+        )
+
+        _manifest_config = self._make_transfer_args(
+            _manifest_config,
+            add_default_tasks=True,
+            extra_tasks=self._settings.upload_tasks or {},
+            job_type=self._settings.job_type,
+            user_email=user_email,
+        )
+        return _manifest_config
+
+    @deprecated("Use _create_manifest_config_from_ads_acquisition instead. This will be removed in a future release.")
+    def _create_manifest_config_from_ads_session(
+        self,
+        ads_session: Session,
         ads_schemas: Optional[List[os.PathLike]] = None,
         session_name: Optional[str] = None,
     ) -> ManifestConfig:
@@ -420,6 +491,11 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         """
         processor_full_name = ",".join(ads_session.experimenter_full_name) or os.environ.get("USERNAME", "unknown")
 
+        if (len(ads_session.experimenter_full_name) > 0) and self._email_from_experimenter_builder is not None:
+            user_email = self._email_from_experimenter_builder(ads_session.experimenter_full_name[0])
+        else:
+            user_email = None
+
         destination = Path(self._settings.destination).resolve()
         source = Path(self._source).resolve()
 
@@ -433,13 +509,13 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         _manifest_config = ManifestConfig(
             name=session_name,
             modalities={
-                str(modality.abbreviation): [str(path.resolve()) for path in [source / str(modality.abbreviation)]]
+                str(modality.abbreviation): [Path(path.resolve()) for path in [source / str(modality.abbreviation)]]
                 for modality in ads_session.data_streams[0].stream_modalities
             },
             subject_id=int(ads_session.subject_id),
             acquisition_datetime=ads_session.session_start_time,
-            schemas=[str(value) for value in ads_schemas],
-            destination=str(destination.resolve()),
+            schemas=[Path(value) for value in ads_schemas],
+            destination=Path(destination),
             mount=self._settings.mount,
             processor_full_name=processor_full_name,
             project_name=self._settings.project_name,
@@ -454,64 +530,92 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             extra_identifying_info=self._settings.extra_identifying_info,
         )
 
-        # TODO
-        _manifest_config = self.add_transfer_service_args(_manifest_config, jobs=self._upload_job_configs)
+        _manifest_config = self._make_transfer_args(
+            _manifest_config,
+            add_default_tasks=True,
+            extra_tasks=self._settings.upload_tasks or {},
+            job_type=self._settings.job_type,
+            user_email=user_email,
+        )
         return _manifest_config
 
-    def add_transfer_service_args(
-        self,
-        manifest_config: ManifestConfig,
-        jobs: List[_JobConfigs] = [],
-        submit_job_request_kwargs: Optional[dict] = None,
-    ) -> ManifestConfig:
-        """
-        Adds transfer service arguments to the manifest configuration.
+    @staticmethod
+    def _remote_destination_root(manifest: ManifestConfig) -> Path:
+        """Determines the remote destination root path for the manifest."""
+        assert manifest.destination is not None, "Manifest destination must be set."
+        assert manifest.name is not None, "Manifest name must be set."
+        return Path(manifest.destination) / manifest.name
 
-        Configures job-specific parameters for different modalities and
-        integrates them into the manifest configuration.
+    @classmethod
+    def _make_transfer_args(
+        cls,
+        manifest: ManifestConfig,
+        *,
+        job_type: str = "default",
+        add_default_tasks: bool = True,
+        extra_tasks: TransferServiceTask,
+        user_email: Optional[str] = None,
+    ) -> ManifestConfig:
+        """Appends extra tasks to a manifest configuration. Additionally appends default
+        metadata and modality transformation tasks if requested."""
+        tasks = {}
+
+        if add_default_tasks:
+            tasks["modality_transformation_settings"] = {
+                modality: aind_data_transfer_service.models.core.Task(
+                    job_settings={"input_source": str(PurePosixPath(cls._remote_destination_root(manifest) / modality))}
+                )
+                for modality in manifest.modalities.keys()
+            }
+
+            tasks["gather_preliminary_metadata"] = aind_data_transfer_service.models.core.Task(
+                job_settings={"metadata_dir": str(PurePosixPath(cls._remote_destination_root(manifest)))}
+            )
+
+        extra_tasks = cls._interpolate_from_manifest(
+            extra_tasks,
+            str(PurePosixPath(cls._remote_destination_root(manifest))),
+            "{{ destination }}",
+        )
+
+        tasks.update(extra_tasks)
+
+        upload_job_configs_v2 = aind_data_transfer_service.models.core.UploadJobConfigsV2(
+            job_type=job_type,
+            project_name=manifest.project_name,
+            platform=aind_data_transfer_service.models.core.Platform.from_abbreviation(manifest.platform),
+            modalities=[
+                aind_data_transfer_service.models.core.Modality.from_abbreviation(m) for m in manifest.modalities.keys()
+            ],
+            subject_id=str(manifest.subject_id),
+            acq_datetime=manifest.acquisition_datetime.strftime("%Y-%m-%d %H:%M:%S"),
+            tasks=tasks,
+            s3_bucket=manifest.s3_bucket,
+            acquisition_datetime=manifest.acquisition_datetime,
+        )
+
+        submit_request_v2 = aind_data_transfer_service.models.core.SubmitJobRequestV2(
+            upload_jobs=[upload_job_configs_v2], user_email=user_email
+        )
+        manifest.transfer_service_args = submit_request_v2
+        return manifest
+
+    @staticmethod
+    def _interpolate_from_manifest(
+        tasks: TransferServiceTask | dict, value: str, placeholder: str
+    ) -> TransferServiceTask:
+        """
+        Interpolates values from the manifest into the upload job configuration.
 
         Args:
-            manifest_config: The manifest configuration to update
-            jobs: List of job configurations
-            submit_job_request_kwargs: Additional arguments for the job request
-
-        Returns:
-            The updated ManifestConfig object
+            upload_job_configs: The upload job configuration to update
+            destination: The destination path to use for interpolation
+            placeholder: The placeholder string to replace
         """
-        # TODO (bruno-f-cruz)
-        # The following code is super hacky and should be refactored once the transfer service
-        # has a more composable API. Currently, the idea is to only allow one job per modality
-
-        # we use the aind-watchdog-service library to create the default transfer service args for us
-        job_settings = aind_watchdog_service.models.make_standard_transfer_args(manifest_config)
-        job_settings = job_settings.model_copy(update=(submit_job_request_kwargs or {}))
-        manifest_config.transfer_service_args = job_settings
-
-        if jobs is None:
-            jobs = []
-            return manifest_config
-
-        def _normalize_callable(job: _JobConfigs) -> ModalityConfigs:
-            """Internal function to normalize job configurations"""
-            if callable(job):
-                return job(self)
-            return job
-
-        modality_configs = [_normalize_callable(job) for job in jobs]
-
-        if len(set([m.modality for m in modality_configs])) < len(modality_configs):
-            raise ValueError("Duplicate modality configurations found. Aborting.")
-
-        for modified in modality_configs:
-            for overridable in manifest_config.transfer_service_args.upload_jobs[0].modalities:
-                if modified.modality == overridable.modality:
-                    # We need to let the watchdog api handle this or we are screwed...
-                    modified.source = overridable.source
-                    manifest_config.transfer_service_args.upload_jobs[0].modalities.remove(overridable)
-                    manifest_config.transfer_service_args.upload_jobs[0].modalities.append(modified)
-                    break
-
-        return manifest_config
+        _adapter = TypeAdapter(TransferServiceTask)
+        literal = _adapter.dump_json(tasks, serialize_as_any=True)
+        updated_literal = literal.decode("utf-8").replace(placeholder, value)
+        return _adapter.validate_json(updated_literal)
 
     @staticmethod
     def _find_ads_schemas(source: PathLike) -> List[PathLike]:
@@ -636,6 +740,10 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             raise ValueError("ManifestConfig or WatchConfig config is not set.")
 
         path = (Path(path) if path else Path(watch_config.flag_dir) / f"manifest_{manifest_config.name}.yaml").resolve()
+
+        if path.suffix not in [".yml", ".yaml"]:
+            path = path.with_suffix(".yaml")
+
         if not path.name.startswith("manifest_"):
             logger.info("Prefix manifest_ not found in file name. Appending it.")
             path = path.with_name(f"manifest_{path.stem}{path.suffix}")
@@ -643,12 +751,10 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
         if make_dir and not path.parent.exists():
             path.parent.mkdir(parents=True, exist_ok=True)
 
-        manifest_config.destination = str(Path.as_posix(Path(manifest_config.destination)))
-        manifest_config.schemas = [str(Path.as_posix(Path(schema))) for schema in manifest_config.schemas]
+        manifest_config.destination = Path(manifest_config.destination)
+        manifest_config.schemas = [Path(schema) for schema in manifest_config.schemas]
         for modality in manifest_config.modalities:
-            manifest_config.modalities[modality] = [
-                str(Path.as_posix(Path(_path))) for _path in manifest_config.modalities[modality]
-            ]
+            manifest_config.modalities[modality] = [_path for _path in manifest_config.modalities[modality]]
 
         self._write_yaml(manifest_config, path)
         return path
@@ -730,8 +836,9 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
     def build_runner(
         cls,
         settings: WatchdogSettings,
-        aind_session_data_mapper: _Promise[Launcher, AindDataSchemaSessionDataMapper] | AindDataSchemaSessionDataMapper,
-    ) -> Callable[[Launcher], "WatchdogDataTransferService"]:
+        aind_session_data_mapper: Promise[[Launcher], TSessionMapper] | TSessionMapper,
+        **kwargs,
+    ) -> Callable[[Launcher], "WatchdogDataTransferService[TSessionMapper]"]:
         """
         A factory method for creating the watchdog service.
 
@@ -749,7 +856,7 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             """Inner callable to create the service from a launcher"""
             _aind_session_data_mapper = (
                 aind_session_data_mapper.result
-                if isinstance(aind_session_data_mapper, _Promise)
+                if isinstance(aind_session_data_mapper, Promise)
                 else aind_session_data_mapper
             )
 
@@ -762,9 +869,7 @@ class WatchdogDataTransferService(DataTransfer[WatchdogSettings]):
             _settings.destination = Path(_settings.destination) / _session.subject
             launcher.copy_logs()
             service = cls(
-                source=launcher.session_directory,
-                settings=_settings,
-                session_name=_session.session_name,
+                source=launcher.session_directory, settings=_settings, session_name=_session.session_name, **kwargs
             ).with_aind_session_data_mapper(_aind_session_data_mapper)
             service.transfer()
             return service
