@@ -1,4 +1,5 @@
 from ._base import Launcher, TModel, TRig, TSession, TTaskLogic
+from ._callable_manager import Promise, ignore_errors, run_if
 from ._cli import LauncherCliArgs
 from ._picker import DefaultBehaviorPicker, DefaultBehaviorPickerSettings
 
@@ -11,4 +12,7 @@ __all__ = [
     "LauncherCliArgs",
     "DefaultBehaviorPicker",
     "DefaultBehaviorPickerSettings",
+    "ignore_errors",
+    "run_if",
+    "Promise",
 ]
